@@ -41,15 +41,21 @@ def get_latest_api_level(product_type: str) -> Union[dict, int]:
 # Configuration for all box types
 
 BOX_TYPE_CONF: dict[str, dict[int, dict[str, Any]]] = {
-    # airSensor
-    "tvLiftBox": {
-        20200518: {
-            "api_path": "/api/device/state",
-            "extended_state_path": "/state/extended",
-            "api": {"set": lambda command: ("GET", f"/s/c/{command}")},
-            "buttons": ["tvLift", {"lift": ""}],
+    # tvLiftBox; in comments api level config description
+    "tvLiftBox": {  # apiType to match devices apiType
+        20200518: {  # apiLevel to match integration level
+            "api_path": "/api/device/state",  # path to devices state
+            "extended_state_path": "/state/extended",  # path to devices extended state
+            "api": {
+                "set": lambda command: ("GET", f"/s/c/{command}")
+            },  # dictionary with interaction methods
+            "buttons": [
+                "tvLift",
+                {"lift": ""},
+            ],  # key used to set platform, list elements used in cls init, e.g. [<alias>, {"path": "state_value"}]
         }
     },
+    # airSensor
     "airSensor": {
         20180403: {
             "api_path": "/api/air/state",
@@ -239,17 +245,6 @@ BOX_TYPE_CONF: dict[str, dict[int, dict[str, Any]]] = {
         }
     },
     "switchBox": {
-        20220114: {
-            "api_path": "/state",
-            "extended_state_path": "/state/extended",
-            "api": {
-                "on": lambda x=None: ("GET", f"/s/{x}/1", None),
-                "off": lambda x=None: ("GET", f"/s/{x}/0", None),
-            },
-            "switches": [
-                ["relay", {"state": lambda x: f"relays/[relay={x}]/state"}, "relay"]
-            ],
-        },
         20180604: {
             "model": "switchBox",
             "api_path": "/api/relay/state",
@@ -259,6 +254,7 @@ BOX_TYPE_CONF: dict[str, dict[int, dict[str, Any]]] = {
                 "off": lambda x=None: ("GET", "/s/0", None),
             },
             "switches": [["0.relay", {"state": "[relay=0]/state"}, "relay"]],
+            # note: does not support power measurement
         },
         20190808: {
             "api_path": "/api/relay/extended/state",
@@ -271,16 +267,86 @@ BOX_TYPE_CONF: dict[str, dict[int, dict[str, Any]]] = {
                 ["0.relay", {"state": lambda x: f"relays/[relay={x}]/state"}, "relay"]
             ],
             "sensors": [
-                ["switchBox.energy", {"energy": "powerMeasuring/powerConsumption/[0]/value",
-                              "measurment_enabled": "powerMeasuring/enabled"}]
-            ]
+                [
+                    "switchBox.energy",
+                    {
+                        "energy": "powerMeasuring/powerConsumption/[0]/value",
+                        "periodS": "powerMeasuring/powerConsumption/[0]/periodS",
+                        "measurment_enabled": "powerMeasuring/enabled",
+                    },
+                ]
+            ],
+        },
+        20200229: {
+            "extended_state_path": "/state/extended",
+            "api_path": "/state/extended",
+            "api": {
+                "on": lambda x=None: ("GET", "/s/1", None),
+                "off": lambda x=None: ("GET", "/s/0", None),
+            },
+            "switches": [
+                ["0.relay", {"state": lambda x: f"relays/[relay={x}]/state"}, "relay"]
+            ],
+            "sensors": [
+                [
+                    "switchBox.energy",
+                    {
+                        "energy": "powerMeasuring/powerConsumption/[0]/value",
+                        "periodS": "powerMeasuring/powerConsumption/[0]/periodS",
+                        "measurment_enabled": "powerMeasuring/enabled",
+                    },
+                ]
+            ],
+        },
+        20200831: {
+            "extended_state_path": "/state/extended",
+            "api_path": "/state/extended",
+            "api": {
+                "on": lambda x=None: ("GET", "/s/1", None),
+                "off": lambda x=None: ("GET", "/s/0", None),
+            },
+            "switches": [
+                ["0.relay", {"state": lambda x: f"relays/[relay={x}]/state"}, "relay"]
+            ],
+            "sensors": [
+                [
+                    "switchBox.energy",
+                    {
+                        "energy": "powerMeasuring/powerConsumption/[0]/value",
+                        "periodS": "powerMeasuring/powerConsumption/[0]/periodS",
+                        "measurment_enabled": "powerMeasuring/enabled",
+                    },
+                ]
+            ],
+        },
+        20220114: {
+            "api_path": "/state/extended",
+            "extended_state_path": "/state/extended",
+            "api": {
+                # note: old control api (i.e. /s/0, /s/1, /s/2) still supported but
+                # now deprecated. switchBox has now API consistent with switchBoxD
+                "on": lambda x=None: ("GET", f"/s/{x}/1", None),
+                "off": lambda x=None: ("GET", f"/s/{x}/0", None),
+            },
+            "switches": [
+                ["relay", {"state": lambda x: f"relays/[relay={x}]/state"}, "relay"]
+            ],
+            "sensors": [
+                [
+                    "switchBox.energy",
+                    {
+                        "energy": "powerMeasuring/powerConsumption/[0]/value",
+                        "periodS": "powerMeasuring/powerConsumption/[0]/periodS",
+                        "measurment_enabled": "powerMeasuring/enabled",
+                    },
+                ]
+            ],
         },
     },
-    # switchBoxD
     "switchBoxD": {
         20190808: {
-            "extended_state_path": "/state/extended",  # tylko dla testów do usunięcia nie w tym api
-            "api_path": "/api/relay/state",
+            "extended_state_path": "/api/relay/extended/state",
+            "api_path": "/api/relay/extended/state",
             "api": {
                 "on": lambda x: ("GET", f"/s/{int(x)}/1", None),
                 "off": lambda x=None: ("GET", f"/s/{int(x)}/0", None),
@@ -299,7 +365,81 @@ BOX_TYPE_CONF: dict[str, dict[int, dict[str, Any]]] = {
                     1,
                 ],
             ],
-        }
+            "sensors": [
+                [
+                    "switchBox.energy",
+                    {
+                        "energy": "powerMeasuring/powerConsumption/[0]/value",
+                        "periodS": "powerMeasuring/powerConsumption/[0]/periodS",
+                        "measurment_enabled": "powerMeasuring/enabled",
+                    },
+                ]
+            ],
+        },
+        20200229: {
+            "extended_state_path": "/state/extended",
+            "api_path": "/state/extended",
+            "api": {
+                "on": lambda x: ("GET", f"/s/{int(x)}/1", None),
+                "off": lambda x=None: ("GET", f"/s/{int(x)}/0", None),
+            },
+            "switches": [
+                [
+                    "0.relay",
+                    {"state": lambda x: f"relays/[relay={x}]/state"},
+                    "relay",
+                    0,
+                ],
+                [
+                    "1.relay",
+                    {"state": lambda x: f"relays/[relay={x}]/state"},
+                    "relay",
+                    1,
+                ],
+            ],
+            "sensors": [
+                [
+                    "switchBox.energy",
+                    {
+                        "energy": "powerMeasuring/powerConsumption/[0]/value",
+                        "periodS": "powerMeasuring/powerConsumption/[0]/periodS",
+                        "measurment_enabled": "powerMeasuring/enabled",
+                    },
+                ]
+            ],
+        },
+        20200831: {
+            "extended_state_path": "/state/extended",
+            "api_path": "/state/extended",
+            "api": {
+                "on": lambda x: ("GET", f"/s/{int(x)}/1", None),
+                "off": lambda x=None: ("GET", f"/s/{int(x)}/0", None),
+            },
+            "switches": [
+                [
+                    "0.relay",
+                    {"state": lambda x: f"relays/[relay={x}]/state"},
+                    "relay",
+                    0,
+                ],
+                [
+                    "1.relay",
+                    {"state": lambda x: f"relays/[relay={x}]/state"},
+                    "relay",
+                    1,
+                ],
+            ],
+            "sensors": [
+                [
+                    "switchBox.energy",
+                    {
+                        "energy": "powerMeasuring/powerConsumption/[0]/value",
+                        "periodS": "powerMeasuring/powerConsumption/[0]/periodS",
+                        "measurment_enabled": "powerMeasuring/enabled",
+                    },
+                ]
+            ],
+        },
     },
     # tempSensor
     "tempSensor": {
@@ -390,7 +530,7 @@ BOX_TYPE_CONF: dict[str, dict[int, dict[str, Any]]] = {
     },
     # wLightBoxS
     "wLightBoxS": {
-        default_api_level:{
+        default_api_level: {
             "api_path": "/api/device/state",
             "api": {
                 "set": lambda x: (
