@@ -1,3 +1,4 @@
+import blebox_uniapi.error
 from .error import MisconfiguredDevice
 from .feature import Feature
 from typing import TYPE_CHECKING, Any, Optional, Type, TypeVar
@@ -8,6 +9,7 @@ if TYPE_CHECKING:
 
 class Gate:
     _control_type: int
+
     def __init__(self, control_type: int):
         self._control_type = control_type
 
@@ -63,6 +65,7 @@ class Shutter(Gate):
             return True
         return False
 
+
 class GateBox(Gate):
     @property
     def is_slider(self) -> bool:
@@ -84,6 +87,8 @@ class GateBox(Gate):
 
         # gate with gateBox visualized:
         #  (0) [   <#####] (100)
+        if current == -1:
+            return None
 
         if desired < current:
             return 0  # closing
@@ -107,8 +112,10 @@ class GateBox(Gate):
     def read_has_stop(self, alias: str, raw_value: Any, product: "Box") -> bool:
         if product.last_data is None:
             return False
-
-        raw = raw_value("extraButtonType")
+        try:
+            raw = raw_value("extraButtonType")
+        except blebox_uniapi.error.JPathFailed:
+            return False
         return 1 == product.expect_int(alias, raw, 3, 0)
 
 
@@ -118,8 +125,12 @@ class GateBoxB(GateBox):
 
         # gate with gateBox visualized:
         #  (0) [   <#####] (100)
+        if current == -1:
+            return None
 
-        if current == 0:  # closed
+        elif 0 < current < 100:
+            return 2  # manually stopped
+        elif current == 0:  # closed
             return 3  # closed (lower/left limit)
 
         return 4  # open (upper/right limit)
@@ -152,7 +163,9 @@ class Cover(Feature):
 
         self._control_type = None
         if extended_state not in [None, {}]:
-            self._control_type = extended_state.get("shutter", {}).get("controlType", {})
+            self._control_type = extended_state.get("shutter", {}).get(
+                "controlType", {}
+            )
 
         self._device_class = dev_class
         self._attributes: GateT = subclass(self._control_type)
