@@ -139,7 +139,9 @@ async def test_without_api_level(mock_session, data, config):
 
 async def test_with_init_failure(mock_session, data, config):
     with patch(
-        "blebox_uniapi.box.AirQuality.many_from_config", spec_set=True, autospec=True
+        "blebox_uniapi.sensor.SensorFactory.many_from_config",
+        spec_set=True,
+        autospec=True,
     ) as mock_sensor:
         mock_sensor.side_effect = KeyError
         with pytest.raises(
@@ -160,6 +162,7 @@ async def test_properties(mock_session, data, config):
     assert "4.56" == box.hardware_version
     assert "BleBox" == box.brand
     assert 20180403 == box.api_version
+    assert "172.1.2.3:80" == box.address
 
 
 async def test_validations(mock_session, data, config):
