@@ -155,7 +155,6 @@ class BleBoxLightEntity(CommonEntity):
 
     async def async_turn_on(self, **kwargs):
         """Turn the light on."""
-        print("async_turn_on:", kwargs)
         rgbw = kwargs.get(ATTR_RGBW_COLOR)
         brightness = kwargs.get(ATTR_BRIGHTNESS)
         effect = kwargs.get(ATTR_EFFECT)
@@ -246,7 +245,9 @@ class TestDimmer(DefaultBoxTest):
     DEVICE_INFO_LATEST = jmerge(
         DEVICE_INFO, patch_version(get_latest_api_level("dimmerBox"))
     )
-    DEVICE_INFO_UNSUPPORTED = jmerge(DEVICE_INFO, patch_version(20170828))
+    DEVICE_INFO_UNSUPPORTED = jmerge(
+        DEVICE_INFO, patch_version(20140828)
+    )  # fake version, default_api_level implemented
 
     DEVICE_INFO_UNSPECIFIED_API = json.loads(
         """
@@ -391,6 +392,12 @@ class TestDimmer(DefaultBoxTest):
         assert entity.is_on is False
         assert entity.brightness == 0
 
+    async def test_unspecified_version(self, aioclient_mock):
+        """
+        As default_api_level implemented for this class of devices, test method shall be omitted.
+        """
+        pass
+
 
 class TestWLightBoxS(DefaultBoxTest):
     """Tests for BleBox wLightBoxS."""
@@ -457,7 +464,7 @@ class TestWLightBoxS(DefaultBoxTest):
     DEVICE_INFO_LATEST = jmerge(
         DEVICE_INFO, patch_version(get_latest_api_level("wLightBoxS"))
     )
-    DEVICE_INFO_UNSUPPORTED = jmerge(DEVICE_INFO, patch_version(20180717))
+    DEVICE_INFO_UNSUPPORTED = jmerge(DEVICE_INFO, patch_version(20140717))
 
     DEVICE_INFO_UNSPECIFIED_API = json.loads(
         """
@@ -535,8 +542,6 @@ class TestWLightBoxS(DefaultBoxTest):
 
         assert entity.name == "My wLightBoxS (wLightBoxS#brightness_mono1)"
         assert entity.unique_id == "BleBox-wLightBoxS-1afe34e750b8-brightness_mono1"
-        print(entity.color_mode)
-        # assert entity.color_mode & SUPPORT_BRIGHTNESS this assertion needs to be refactored, after extended state will be mockable
         assert entity.brightness is None
 
         assert entity.is_on is None
@@ -563,13 +568,11 @@ class TestWLightBoxS(DefaultBoxTest):
         """Test light updating."""
 
         entity = await self.updated(aioclient_mock, self.STATE_DEFAULT)
-        print("TU:", entity.color_mode)
         assert entity.brightness == 0xAB
         assert entity.is_on is True
 
     async def allow_set_brightness(self, code, aioclient_mock, value, response):
         """Set up mock for HTTP POST simulating color change."""
-        print("allow_set_brightness", response)
         raw = "{:02x}".format(value)
         await self.allow_post(
             code,
@@ -584,7 +587,6 @@ class TestWLightBoxS(DefaultBoxTest):
     async def test_on(self, aioclient_mock):
         """Test light on."""
         entity = await self.updated(aioclient_mock, self.STATE_OFF)
-        print("Ent: ", entity)
         assert entity.is_on is False
 
         async def turn_on():
@@ -603,7 +605,7 @@ class TestWLightBoxS(DefaultBoxTest):
         assert entity.is_on is False
 
         with pytest.raises(
-            BadOnValueError,
+            ValueError,
             match=r"adjust_brightness called with bad parameter \(00 is <class 'str'> instead of int\)",
         ):
             await entity.async_turn_on(brightness="00")
@@ -614,7 +616,7 @@ class TestWLightBoxS(DefaultBoxTest):
         assert entity.is_on is False
 
         with pytest.raises(
-            BadOnValueError,
+            ValueError,
             match=r"adjust_brightness called with bad parameter \(1234 is greater than 255\)",
         ):
             await entity.async_turn_on(brightness=1234)
@@ -632,6 +634,12 @@ class TestWLightBoxS(DefaultBoxTest):
         assert entity.is_on is False
         assert entity.brightness == 0
 
+    async def test_unspecified_version(self, aioclient_mock):
+        """
+        As default_api_level implemented for this class of devices, test method shall be omitted.
+        """
+        pass
+
 
 class TestWLightBox(DefaultBoxTest):
     """Tests for BleBox wLightBox."""
@@ -765,7 +773,7 @@ class TestWLightBox(DefaultBoxTest):
     DEVICE_INFO_LATEST = jmerge(
         DEVICE_INFO, patch_version(get_latest_api_level("wLightBox"))
     )
-    DEVICE_INFO_UNSUPPORTED = jmerge(DEVICE_INFO, patch_version(20180717))
+    DEVICE_INFO_UNSUPPORTED = jmerge(DEVICE_INFO, patch_version(20140717))
 
     DEVICE_INFO_UNSPECIFIED_API = json.loads(
         """
@@ -886,7 +894,6 @@ class TestWLightBox(DefaultBoxTest):
 
     async def allow_set_color(self, code, aioclient_mock, value, response):
         """Set up mock for HTTP POST simulating color change."""
-        print("allow_set_color", response)
         await self.allow_post(
             code,
             aioclient_mock,
@@ -926,33 +933,6 @@ class TestWLightBox(DefaultBoxTest):
         assert entity.is_on is False
         # assert entity.white_value == 0x00
 
-    async def test_ancient_response(self, aioclient_mock):
-        """Test e.g. unsupported, ancient device status structure."""
-
-        DEVICE_INFO_ANCIENT_STRUCTURE = json.loads(
-            """
-            {
-                "deviceName": "My light 1",
-                "type": "wLightBox",
-                "fv": "0.623",
-                "hv": "0.3",
-                "universe": 0,
-                "id": "6201943ff9c9",
-                "ip": "192.168.9.45"
-            }
-            """
-        )
-
-        await self.allow_get_info(aioclient_mock, DEVICE_INFO_ANCIENT_STRUCTURE)
-        with pytest.raises(UnsupportedBoxVersion):
-            await self.async_entities(aioclient_mock)
-
-    """
-        1. ustawic setup mocka do inicjalizacji obiektu
-        2. dostep do encji
-        3. asercje
-    """
-
     async def test_colormode_5_brightness(self, aioclient_mock):
         self.DEVICE_EXTENDED_INFO = self.DEVICE_EXTENDED_INFO_COLORMODE_5
         await self.allow_get_info(aioclient_mock)
@@ -971,9 +951,6 @@ class TestWLightBox(DefaultBoxTest):
         assert "_cct2" in entity.name
         assert entity.brightness
 
-    async def test_many_from_config_check_empty(self, aioclient_mock):
-        pass
-
     async def test_effect_list_return_list(self, aioclient_mock):
         self.DEVICE_EXTENDED_INFO = self.DEVICE_EXTENDED_INFO_COLORMODE_5
         await self.allow_get_info(aioclient_mock)
@@ -1015,7 +992,6 @@ class TestWLightBox(DefaultBoxTest):
         )
 
         await self.allow_get_info(aioclient_mock)
-        print("INTEST:\n", self.DEVICE_EXTENDED_INFO, "\nEntity:\n")
         entity = await self.updated(aioclient_mock, self.STATE_DEFAULT)
 
         async def turn_on():
@@ -1040,7 +1016,6 @@ class TestWLightBox(DefaultBoxTest):
         )
 
         await self.allow_get_info(aioclient_mock)
-        print("INTEST:\n", self.DEVICE_EXTENDED_INFO, "\nEntity:\n")
         entity = await self.updated(aioclient_mock, self.STATE_DEFAULT)
 
         async def turn_on():
@@ -1090,13 +1065,11 @@ class TestWLightBox(DefaultBoxTest):
         self.STATE_DEFAULT["colorMode"] = 5
         entity = await self.updated(aioclient_mock, self.STATE_DEFAULT)
 
-        print("INTEST:\n", entity.name, "\nEntity:\n")
-
         async def turn_on():
             await entity.async_turn_on()
 
         self.STATE_ON = jmerge(self.STATE_ON, self.patch_state("ffffffff", "ffffffff"))
-        await self.allow_set_color(turn_on, aioclient_mock, "ffff------", self.STATE_ON)
+        await self.allow_set_color(turn_on, aioclient_mock, "ffff----", self.STATE_ON)
 
         assert entity.color_temp == 128
 
@@ -1108,14 +1081,12 @@ class TestWLightBox(DefaultBoxTest):
         self.STATE_DEFAULT["colorMode"] = 5
         entity = await self.updated(aioclient_mock, self.STATE_DEFAULT)
 
-        print("INTEST:\n", entity.name, "\nEntity:\n")
-
         async def turn_on():
             await entity.async_turn_on(color_temp=1)
 
         self.STATE_ON = jmerge(self.STATE_ON, self.patch_state("02ffffff", "02ffffff"))
 
-        await self.allow_set_color(turn_on, aioclient_mock, "02fa------", self.STATE_ON)
+        await self.allow_set_color(turn_on, aioclient_mock, "02fa----", self.STATE_ON)
 
         assert entity.color_temp == 1
 
@@ -1132,7 +1103,7 @@ class TestWLightBox(DefaultBoxTest):
 
         self.STATE_ON = jmerge(self.STATE_ON, self.patch_state("fa00ffff", "fa02ffff"))
 
-        await self.allow_set_color(turn_on, aioclient_mock, "fa00------", self.STATE_ON)
+        await self.allow_set_color(turn_on, aioclient_mock, "fa00----", self.STATE_ON)
 
         assert entity.color_temp == 255
 
@@ -1149,7 +1120,7 @@ class TestWLightBox(DefaultBoxTest):
 
         self.STATE_ON = jmerge(self.STATE_ON, self.patch_state("fa00ffff", "fa02ffff"))
 
-        await self.allow_set_color(turn_on, aioclient_mock, "fa00------", self.STATE_ON)
+        await self.allow_set_color(turn_on, aioclient_mock, "fa00----", self.STATE_ON)
 
         assert entity.color_temp == 255
 
@@ -1174,6 +1145,12 @@ class TestWLightBox(DefaultBoxTest):
 
         assert entity.rgbww_color == (0, 0, 0, 120, 214)
 
+    async def test_unspecified_version(self, aioclient_mock):
+        """
+        As default_api_level implemented for this class of devices, test method shall be omitted.
+        """
+        pass
+
 
 def test_unit_light_evaluate_brightness_from_rgb():
     tested_ob = Light.evaluate_brightness_from_rgb(iterable=(140, 230))
