@@ -152,8 +152,7 @@ class TestSwitchBox(DefaultBoxTest):
     DEVCLASS = "switches"
     ENTITY_CLASS = BleBoxSwitchEntity
 
-    DEV_INFO_PATH = "api/relay/state"
-
+    DEV_INFO_PATH = "api/relay/extended/state"
     DEVICE_INFO = json.loads(
         """
     {
@@ -276,7 +275,7 @@ class TestSwitchBoxD(DefaultBoxTest):
     DEVCLASS = "switches"
     ENTITY_CLASS = BleBoxSwitchEntity
 
-    DEV_INFO_PATH = "api/relay/state"
+    DEV_INFO_PATH = "state/extended"
 
     DEVICE_INFO = json.loads(
         """
@@ -287,7 +286,7 @@ class TestSwitchBoxD(DefaultBoxTest):
             "fv": "0.200",
             "hv": "0.7",
             "id": "1afe34e750b8",
-            "apiLevel": "20190808"
+            "apiLevel": "20200831"
         }
     }
     """
